@@ -7,13 +7,13 @@ import click
 
 from mldock.config_managers.core import WorkingDirectoryManager
 from mldock.config_managers.container import MLDockConfigManager
-
+from mldock.platform_helpers import utils
 from mldock.config_managers.cli import \
     PackageConfigManager, HyperparameterConfigManager, \
         InputDataConfigManager, StageConfigManager, \
             ModelConfigManager, EnvironmentConfigManager, CliConfigureManager
 
-from mldock.api.templates import init_from_template
+from mldock.api.templates import init_from_template, check_available_templates
 
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
@@ -63,6 +63,11 @@ def container():
     default=None,
     help='Directory containing mldock supported container to use to initialize the container.'
 )
+@click.option(
+    '--requirements',
+    default=None,
+    help='path to requirements file.'
+)
 @click.option(
     '--params',
     '-p',
@@ -79,6 +84,34 @@ def container():
     type=click.Tuple([str, str]),
     multiple=True
 )
+@click.option(
+    '--trainer-script',
+    help='provide a path to your trainer script.',
+    type=click.Path(
+        exists=False,
+        file_okay=True,
+        dir_okay=False,
+        writable=True,
+        readable=True,
+        resolve_path=False,
+        allow_dash=False,
+        path_type=None
+    )
+)
+@click.option(
+    '--prediction-script',
+    help='provide a path to your prediction script.',
+    type=click.Path(
+        exists=False,
+        file_okay=True,
+        dir_okay=False,
+        writable=True,
+        readable=True,
+        resolve_path=False,
+        allow_dash=False,
+        path_type=None
+    )
+)
 @click.pass_obj
 def init(obj, project_directory, **kwargs):
     """
@@ -87,22 +120,42 @@ def init(obj, project_directory, **kwargs):
     no_prompt = kwargs.get('no_prompt', False)
     container_only = kwargs.get('container_only', False)
     template = kwargs.get('template', 'generic')
+    requirements = kwargs.get('requirements', None)
     params = kwargs.get('params', None)
     env_vars = kwargs.get('env_vars', None)
+    trainer_script = kwargs.get('trainer_script', None)
+    prediction_script = kwargs.get('prediction_script', None)
 
     reset_terminal()
     mldock_package_path = obj['mldock_package_path']
     try:
         click.secho("Initializing MLDock project configuration", bg='blue', nl=True)
 
-        if not Path(project_directory).is_dir():
-            create_new = click.prompt('No MLDOCK project found. Create?', type=bool)
+        if not Path(project_directory, 'mldock.json').is_file():
+            create_new = click.prompt('No MLDOCK project found. Create?', type=bool, default='no')
         else:
             create_new = False
 
+        # check template config
+        config_manager = CliConfigureManager()
+        templates = config_manager.templates
+
+        # get configured template server metadata
+        # if not set, default to package default templates
+        templates_root = templates.get('templates_root', Path(mldock_package_path, 'templates'))
+        # if not set, default to local
+        template_server = templates.get('server_type', 'local')
+
+        # get available templates
+        available_templates = check_available_templates(
+            templates_root=templates_root,
+            template_server=template_server
+        )
+
         mldock_manager = MLDockConfigManager(
             filepath=Path(project_directory, MLDOCK_CONFIG_NAME),
-            create=create_new
+            create=create_new,
+            available_templates=available_templates
         )
 
         if template is not None:
@@ -129,16 +182,9 @@ def init(obj, project_directory, **kwargs):
         if not no_prompt:
             mldock_manager.setup_config()
 
-        package_dir = mldock_manager.get_config().get('requirements', project_directory)
-        package_manager = PackageConfigManager(
-            filepath=os.path.join(package_dir, "requirements.txt"),
-            create=True
-        )
-        # write to package manager
-        package_manager.write_file()
+        # finally delete original
 
-
-        path_to_payload = Path(os.path.join(project_directory, "payload.json"))
+        path_to_payload = Path(project_directory, "payload.json")
         if not path_to_payload.exists():
             path_to_payload.write_text(json.dumps({"feature1": 10, "feature2":"groupA"}))
 
@@ -202,23 +248,32 @@ def init(obj, project_directory, **kwargs):
         # Get template specific files
         template = mldock_config["template"]
 
-        config_manager = CliConfigureManager()
-        templates = config_manager.templates
-
-        # get configured template server metadata
-        # if not set, default to package default templates
-        templates_root = templates.get('templates_root', Path(mldock_package_path, 'templates'))
-        # if not set, default to local
-        template_server = templates.get('server_type', 'local')
-
         init_from_template(
             template_name=template,
             templates_root=templates_root,
             src_directory=src_directory,
             container_only=container_only,
-            template_server=template_server
+            template_server=template_server,
+            trainer_script=trainer_script,
+            prediction_script=prediction_script
         )
 
+        # always setup requirements in src/
+        package_dir = mldock_manager.get_config().get('requirements_dir', 'src/requirements.txt')
+        requirement_file = Path(project_directory, package_dir)
+        if requirements is not None:
+            logger.info(f"Copying {requirements} => {requirement_file.as_posix()}")
+            utils.copy_file(
+                requirements,
+                requirement_file
+            )
+
+        package_manager = PackageConfigManager(
+            filepath=requirement_file,
+            create=(requirement_file.is_file() == False)
+        )
+        package_manager.write_file()
+
         states = mldock_manager.get_state()
 
         for state in states:
