@@ -12,7 +12,7 @@ def get_aws_ecr(region: str):
 
         args:
             region (str): AWS region of the registry to authenticate
-        
+
         return:
             username (str): username to use in docker client auth
             password (str): password token to use in docker client auth
@@ -20,11 +20,16 @@ def get_aws_ecr(region: str):
     """
     # this loads AWS access token and secret from env and returns an ECR client
     ecr_client = boto3.client('ecr', region_name=region)
+
     # get login token
     token = ecr_client.get_authorization_token()
-    username, password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
-    password = base64.b64decode(token["authorizationData"][0]["authorizationToken"]).decode().split(":")[1]
+
+    username, password = base64.b64decode(
+        token['authorizationData'][0]['authorizationToken']
+    ).decode().split(':')
+
     registry = token['authorizationData'][0]['proxyEndpoint']
+
     cloud_repository = strip_scheme(registry)
     # return docker credentials
     return username, password, registry, cloud_repository
